VrConstants class

Constructors

VrConstants()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

panoramaImageUrl1 → const String
panoramaImageUrl2 → const String
vrDemoUrl → const String
vrVideoUrl → const String
vrVideoUrl2 → const String