NeomVR360Engine class
Audio-reactive VR 360 engine built on sint_vr.
Manages particles, rings, constellations, and audio state. Delegates projection and stereoscopic rendering to sint_vr.
- Inheritance
-
- Object
- ChangeNotifier
- NeomVR360Engine
Constructors
Properties
- accentColor ↔ Color
-
getter/setter pair
- audioAmplitude ↔ double
-
getter/setter pair
- audioBeat ↔ double
-
getter/setter pair
- audioCoherence ↔ double
-
getter/setter pair
- audioFrequency ↔ double
-
getter/setter pair
- audioPhase ↔ double
-
getter/setter pair
- camera → VRCamera
-
The VR camera (from sint_vr).
final
-
constellations
↔ List<
_AudioParticle> -
getter/setter pair
- eyeSeparation ↔ double
-
Eye separation (delegates to projection).
getter/setter pair
- frequencyModulatedColor → Color
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- normalizedFrequency → double
-
no setter
- particleCount ↔ int
-
getter/setter pair
-
particles
↔ List<
_AudioParticle> -
getter/setter pair
- primaryColor ↔ Color
-
getter/setter pair
- projection → StereoscopicProjection
-
Stereoscopic projection (from sint_vr).
final
- ringCount ↔ int
-
getter/setter pair
-
rings
↔ List<
_AudioParticle> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scene → VRScene
-
The underlying VR scene (from sint_vr).
final
- secondaryColor ↔ Color
-
getter/setter pair
- showConstellations ↔ bool
-
getter/setter pair
- showNebula ↔ bool
-
getter/setter pair
- showRings ↔ bool
-
getter/setter pair
- wavelength ↔ double
-
getter/setter pair
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
initialize(
) → void - Initializes the VR universe.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setColorTheme(
String mode) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update(
double dt) → void -
updateAudio(
{required double amplitude, required double frequency, required double beat, required double phase, required double coherence, double? waveLen}) → void -
updateCamera(
double deltaTheta, double deltaPhi) → void - Delegates camera rotation to sint_vr VRCamera.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited